@@ -21,7 +21,7 @@
 
 casti <- function() {
 
-  remote_path <- 'http://rczechia.jla-data.net/'
+  remote_path <- 'https://rczechia.jla-data.net/'
 
   file <- 'casti.rds'
 
@@ -34,14 +34,14 @@ casti <- function() {
 
   } else {
 
-    if (http_error(remote_file)) {
+    if (httr::http_error(remote_file)) {
 
       stop('No internet connection or data source broken.')
 
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      curl_download(url = remote_file, destfile = local_file, quiet = T)
+      curl::curl_download(url = remote_file, destfile = local_file, quiet = T)
     }
   }
 
