@@ -28,7 +28,7 @@
 
 kraje <- function(resolution = "high") {
 
-  remote_path <- 'http://rczechia.jla-data.net/'
+  remote_path <- 'https://rczechia.jla-data.net/'
 
   file <- 'Kraje.rds'
 
@@ -49,14 +49,14 @@ kraje <- function(resolution = "high") {
 
     } else {
 
-      if (http_error(remote_file)) {
+      if (httr::http_error(remote_file)) {
 
         stop('No internet connection or data source broken.')
 
       } else {
 
         message('RCzechia: downloading remote dataset.')
-        curl_download(url = remote_file, destfile = local_file, quiet = T)      }
+        curl::curl_download(url = remote_file, destfile = local_file, quiet = T)      }
     }
 
     local_df <- readRDS(local_file)
